@@ -1,4 +1,4 @@
-#!/usr/bin/python2.5
+#!/usr/bin/python
 
 # Copyright (c) 2011 Christos Zamantzas
 # Licenced under GPLv2
@@ -219,28 +219,29 @@ class CSSUfeaturesFixConfig(QtGui.QMainWindow):
        aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
        #aboutIcon.resize(128,128)
        aboutLayout.addWidget(aboutIcon)
-       
-       aboutLabel = QLabel(''' <center><b>Disclaimer/Warning</b>
-                               <br>The transitions.ini file in this system
-                               <br>does not have all the needed options.
-                               <br>A repair operation can be initiated but
-                               <br>the result cannot be guaranteed.
-                               <br>
-                               <br>Meaning, the system might enter in a
-                               <br>reboot loop and an advanced repair or
-                               <br>reflash might be needed.
-                               </center>''')
+
+       aboutLabel = QLabel('''<b>Warning: </b>The transitions.ini file in this system does not have all the expected options. <br> <br> <b>Disclaimer: </b>A repair operation can be initiated but the result cannot be guaranteed. That is, the system might enter in a reboot loop and a reflash of the OS might be needed. The safest option is to choose the restoration of the default file.''')
+       aboutLabel.setWordWrap(True)
+       aboutLabel.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
        aboutLayout.addWidget(aboutLabel)
        
-       self.fix_button = QPushButton('Fix Config')
-       self.fix_button.clicked.connect(self.fixConfigVariables)
-       self.cancel_button = QPushButton('Exit')
-       self.cancel_button.clicked.connect(self.cancel)
+       self.buttonFixConfig = QPushButton('Fix Config')
+       self.buttonFixConfig.clicked.connect(self.fixConfigVariables)
+       self.buttonRestoreConfig = QPushButton('Restore Default')
+       self.buttonRestoreConfig.clicked.connect(self.restoreDefaultConfigFile)
+       self.buttonExit = QPushButton('Exit')
+       self.buttonExit.clicked.connect(self.cancel)
+
        awidget2 = QWidget()
        buttonLayout = QHBoxLayout(awidget2)        
-       buttonLayout.addWidget(self.fix_button)
-       buttonLayout.addWidget(self.cancel_button)
+       buttonLayout.addWidget(self.buttonFixConfig)
+       buttonLayout.addWidget(self.buttonRestoreConfig)
        aboutLayout.addWidget(awidget2)
+
+       awidget3 = QWidget()
+       buttonLayout = QHBoxLayout(awidget3)
+       buttonLayout.addWidget(self.buttonExit)
+       aboutLayout.addWidget(awidget3)
         
        awidget.setLayout(aboutLayout)
        aboutScrollArea.setWidget(awidget)
@@ -321,14 +322,30 @@ class CSSUfeaturesFixConfig(QtGui.QMainWindow):
 
        message += 'End of fixing\n\n'
        message += 'The application will now exit..'
-       #aboutLabel = QLabel(''' <center><b>UPDATING</b><br>%s</center>''' % message)  
        showMessage(message)
-       getCurrent()
-       copyConfigFile()
+       # getCurrent()
+       # copyConfigFile()
        time.sleep(5)
        # self.close()   
        sys.exit(1)
 
+    def restoreDefaultConfigFile(self):
+       ''' Restore the default configuration file.'''
+      
+       try:
+          os.system('sudo %s%s copyDefault' % (PathApp, updateSettings))
+       except:
+          message = 'ERROR: The default transitions.ini file could not be restored to the system.\n\n'
+       else: 
+          message = 'The default transitions.ini file have been restored to the system.\nINFO: Some of its settings will appear on the next reboot.\n\n'
+
+       message += 'The application will now exit..'
+       showMessage(message)
+       # getCurrent()
+       # copyConfigFile()
+       time.sleep(5)
+       # self.close()   
+       sys.exit(1)
 
 class CSSUfeaturesAbout(QtGui.QMainWindow):
     '''About Window'''
@@ -342,7 +359,7 @@ class CSSUfeaturesAbout(QtGui.QMainWindow):
        aboutScrollArea = QScrollArea(self)
        aboutScrollArea.setWidgetResizable(True)
        awidget = QWidget(aboutScrollArea)
-       awidget.setMinimumSize(470,1000)
+       #awidget.setMinimumSize(470,1000)
        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        #Kinetic scroller is available on Maemo and should be on meego
@@ -355,40 +372,22 @@ class CSSUfeaturesAbout(QtGui.QMainWindow):
        aboutLayout = QVBoxLayout(awidget)
 
        aboutIcon = QLabel()
-       aboutIcon.setPixmap( QIcon.fromTheme('CSSUfeatures').pixmap(64,64) )
-       aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
+       aboutIcon.setPixmap( QIcon.fromTheme('CSSUfeatures').pixmap(128,128))
        aboutIcon.resize(128,128)
+       aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
        aboutLayout.addWidget(aboutIcon)
 
-       aboutLabel = QLabel(''' <center><b>CSSU Features Configuration</b> %s
-                               <br>
-                               <br>
-                               <b>The CSSU Features application is 
-                               <br>a user interface to the configuration 
-                               <br>of several parameters enabled  
-                               <br>by the Community SSU updates.</b>
-                               <br>
-                               <br>Licenced under GPLv2
-                               <br>by <b>Christos Zamantzas</b> (Saturn)
-                               <br>
-                               <br>It provides the ability to change a number 
-                               <br>of parameters while in operation by  
-                               <br>modifing options in the transitions.ini  
-                               <br>configuration file. 
-                               <br>
-                               <br>
-                               <b>Additional information on the usage, 
-                               <br>settings and implications can be found 
-                               <br>in the wiki page</b>
-                               <br>
-                               <br>
-                               <br><b>Thanks to :</b>
-                               <br><b>Benoit HERVIER</b> at http://khertan.net/
-                               <br>for the code used in this about window
-                               <br>and the pyPackager utility.
-                               <br>
-                               </center>''' % Version)
+       aboutLabel = QLabel('''<center><b>CSSU Features Configuration</b> %s 
+       <br><br><b>The CSSU Features application is a user interface to the configuration of several system parameters enabled by the Community SSU updates.</b>
+       <br><br>Licenced under GPLv2
+       <br>by <b>Christos Zamantzas</b> (Saturn)
+       <br><br>It provides the ability to change a number of parameter values by modifing several options in the transitions.ini configuration file as well as in the GConf configuration system.
+       <br><br><b>Additional information on the usage, settings and implications can be found in the wiki page</b>
+       <br><br>Thanks go to: <b>Benoit HERVIER</b> at http://khertan.net/ for the example code used in this about window and the pyPackager utility.<br></center>''' % Version)
+       aboutLabel.setWordWrap(True)
+       aboutLabel.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
        aboutLayout.addWidget(aboutLabel)
+       
        self.bugtracker_button = QPushButton('BugTracker')
        self.bugtracker_button.clicked.connect(self.open_bugtracker)
        self.website_button = QPushButton('Wiki Page')
